yarp_stats {#master}
-------------------------

## Important Changes

### Yarp companion

#### added command `yarp stats`
* `yarp stats` opens a temporary port to receive data from a remote port (at maximum speed). It also prints basic statistics about data trasferred on the instantiated connection.
